Other helpful information
===========================
This section includes some additional information you might find helpful and that spans the various *guides*, like troubleshooting and related resources.

.. toctree::
   :maxdepth: 1
   :name: other

   troubleshooting
   related-resources
